<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
  xmlns:fo="http://www.w3.org/1999/XSL/Format"
  xmlns:s6hl="http://net.sf.xslthl/ConnectorSaxon6"
  xmlns:sbhl="http://net.sf.xslthl/ConnectorSaxonB"
  xmlns:xhl="http://net.sf.xslthl/ConnectorXalan"

  xmlns:saxon6="http://icl.com/saxon"
  xmlns:saxonb="http://saxon.sf.net/"
  xmlns:xalan="http://xml.apache.org/xalan"

  xmlns:xslthl="http://xslthl.sf.net"
  extension-element-prefixes="s6hl sbhl xhl xslthl">
  
  <!-- import Docbook XSL stylesheet -->
  <xsl:import href="/usr/share/xml/docbook/stylesheet/nwalsh/fo/docbook.xsl"/>

  <!-- adjust properties - see http://www.docbook.org/tdg/en/html/docbook.html for a reference-->
  <xsl:param name="admon.graphics" select="1"/>
  <xsl:param name="highlight.source" select="1" />
  <xsl:param name="line-height">150%</xsl:param>

  <xsl:param name="paper.type" select="'A4'"/>
  <xsl:param name="admon.graphics.path">/usr/share/xml/docbook/stylesheet/nwalsh/images/</xsl:param>
  <xsl:param name="admon.graphics.extension">.svg</xsl:param>
  <xsl:param name="callout.graphics.path">/usr/share/doc/docbook-xsl/doc/images/callouts/</xsl:param>

  <!-- The header file which is used -->
  <xsl:param name="header.image.filename">images/f3_logo.svg</xsl:param>

  <xsl:param name="fop.extensions" select="0"/>
  <xsl:param name="fop1.extensions" select="1"/>
  <!-- Make the variablelists render like definition lists in HTML -->
  <xsl:param name="variablelist.term.break.after" select="1"/>
  <xsl:param name="variablelist.as.blocks" select="1"></xsl:param>

  <xsl:param name="section.autolabel" select="1"/>
  <xsl:param name="generate.chapter.toc" select="0"/>
  <xsl:param name="body.font.family">sans-serif</xsl:param>
  <xsl:param name="dingbat.font.family">sans-serif</xsl:param>
  <xsl:param name="title.font.family">Share-Regular</xsl:param>


  <!-- Define the layout of the caption of tables/examples and figures-->
  <xsl:attribute-set name="formal.title.properties">
    <xsl:attribute name="font-size">80%</xsl:attribute>
    <xsl:attribute name="font-family">Share-Regular</xsl:attribute>
    <xsl:attribute name="hyphenate">false</xsl:attribute>
    <xsl:attribute name="space-after.minimum">0.4em</xsl:attribute>
    <xsl:attribute name="space-after.optimum">0.6em</xsl:attribute>
    <xsl:attribute name="space-after.maximum">0.8em</xsl:attribute>
    <xsl:attribute name="keep-together.within-column">always</xsl:attribute>
  </xsl:attribute-set>

  <!-- Define vertical placement of titles -->
  <xsl:param name="formal.title.placement">
    figure after
    example after
    table after
    procedure after
  </xsl:param>

  <xsl:attribute-set name="admonition.title.properties">
    <xsl:attribute name="font-size">14pt</xsl:attribute>
    <xsl:attribute name="font-family">Share-Regular</xsl:attribute>
    <xsl:attribute name="hyphenate">false</xsl:attribute>
    <xsl:attribute name="keep-with-next.within-column">always</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="formal.object.properties">
    <xsl:attribute name="keep-together.within-column">always</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="list.item.spacing">
    <xsl:attribute name="space-before.optimum">0.5em</xsl:attribute>
    <xsl:attribute name="space-before.minimum">0.3em</xsl:attribute>
    <xsl:attribute name="space-before.maximum">0.7em</xsl:attribute>
  </xsl:attribute-set>

  <xsl:attribute-set name="normal.para.spacing">
    <xsl:attribute name="space-before.optimum">0.5em</xsl:attribute>
    <xsl:attribute name="space-before.minimum">0.3em</xsl:attribute>
    <xsl:attribute name="space-before.maximum">0.7em</xsl:attribute>
  </xsl:attribute-set>

  <!-- Programlisting configuration -->
  <xsl:attribute-set name="monospace.verbatim.properties">
    <!-- Enable the line below to use the Share-Tech font for program listing -->
    <!-- <xsl:attribute name="font-family">Share-TechMono</xsl:attribute> -->
    <xsl:attribute name="font-size">85%</xsl:attribute>
    <xsl:attribute name="line-height">normal</xsl:attribute>
  </xsl:attribute-set>

  <!-- Image configuration -->
  <xsl:attribute-set name="figure.properties">
    <xsl:attribute name="text-align">center</xsl:attribute>
  </xsl:attribute-set>


  <!-- Header configuration -->
  <!-- No ruler below the header -->
  <xsl:param name="header.rule">0</xsl:param>
  <!-- template to overrule the default header content. -->
  <xsl:template name="header.content">
    <xsl:param name="pageclass" select="''"/>
    <xsl:param name="sequence" select="''"/>
    <xsl:param name="position" select="''"/>
    <xsl:param name="gentext-key" select="''"/>

    <!-- sequence can be odd, even, first, blank -->
    <!-- position can be left, center, right -->
    <fo:block>
    <xsl:choose>
      <xsl:when test="$sequence = 'blank'">
        <!-- nothing -->
      </xsl:when>

      <xsl:when test="$position='left'">
        <!-- Same for odd, even, empty, and blank sequences -->
          <xsl:if test="$pageclass != 'titlepage'">
            <fo:block space-before="-0.5em">
	    <fo:external-graphic content-height="0.6cm">
              <xsl:attribute name="src">
              <xsl:call-template name="fo-external-image">
                <xsl:with-param name="filename" select="$header.image.filename"/>
              </xsl:call-template>
            </xsl:attribute>
          </fo:external-graphic>
          </fo:block>
        </xsl:if>
      </xsl:when>

      <xsl:when test="$position='center'">
        <!-- nothing for empty and blank sequences -->
      </xsl:when>

      <xsl:when test="$position='right'">
        <!-- Same for odd, even, empty, and blank sequences -->
      </xsl:when>

      <xsl:when test="$sequence = 'first'">
        <!-- nothing for first pages -->
      </xsl:when>

      <xsl:when test="$sequence = 'blank'">
        <!-- nothing for blank pages -->
      </xsl:when>
    </xsl:choose>
  </fo:block>

  </xsl:template>

  <!-- Enable highlighting -->
  <!-- for Xalan 2.7 -->
  <xalan:component prefix="xhl" functions="highlight">
    <xalan:script lang="javaclass" src="xalan://net.sf.xslthl.ConnectorXalan" />
  </xalan:component>
 
  <!-- for saxon 6 -->
  <saxon6:script implements-prefix="s6hl" language="java"
    src="java:net.sf.xslthl.ConnectorSaxon6" />
 
  <!-- for saxon 8.5 and later -->
  <saxonb:script implements-prefix="sbhl" language="java"
    src="java:net.sf.xslthl.ConnectorSaxonB" />

</xsl:stylesheet>
